@@ -266,7 +266,7 @@ class zetl:
 	def logend_steptable(self,dbconn,lid,script_variables,steptablename,script_output,database=''):
 		tblrowcount = 0
 		qualified_table = ''
-		if 'DB_TYPE' in script_variables: # dont use default connection
+		if script_variables['DB_TYPE'] != '': # dont use default connection
 			if script_variables['DB_TYPE'].upper() == 'MYSQL':
 				qualified_table = steptablename
 			elif (script_variables['DB_TYPE'].upper() == 'POSTGRES'):
@@ -275,7 +275,7 @@ class zetl:
 					this_schema = steptablename.split('.')[0]
 				except:
 					this_table = steptablename
-					if 'DB_SCHEMA' in script_variables:
+					if script_variables['DB_SCHEMA'] != '':
 						this_schema = script_variables['DB_SCHEMA']
 					else:
 						this_schema = 'public'
@@ -293,7 +293,7 @@ class zetl:
 				this_schema = steptablename.split('.')[0]
 			except:
 				this_table = steptablename
-				if 'DB_SCHEMA' in script_variables:
+				if script_variables['DB_SCHEMA'] != '':
 					this_schema = script_variables['DB_SCHEMA']
 				else:
 					this_schema = 'public'
@@ -612,8 +612,8 @@ class zetldbaccess:
 										self.add_etl_step(etl_name,etl_step,etl_script_file)		
 
 if __name__ == '__main__':
-	#main()
-	zetl().forcerun('LoadPostalCodes')
+	main()
+	#zetl().forcerun('LoadPostalCodes')
 
 		
 
